summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyselector.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit902ba103f2215bcefa22d62b1c9138aa4b88891c (patch)
tree63ef88424b9be33a31e5a8de61343fb8d7633937 /kmymoney2/widgets/kmymoneyselector.cpp
parent7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2 (diff)
downloadkmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.tar.gz
kmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/widgets/kmymoneyselector.cpp')
-rw-r--r--kmymoney2/widgets/kmymoneyselector.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kmymoney2/widgets/kmymoneyselector.cpp b/kmymoney2/widgets/kmymoneyselector.cpp
index b4af52f..17428ce 100644
--- a/kmymoney2/widgets/kmymoneyselector.cpp
+++ b/kmymoney2/widgets/kmymoneyselector.cpp
@@ -36,8 +36,8 @@
#include "../kmymoneyglobalsettings.h"
-KMyMoneySelector::KMyMoneySelector(TQWidget *tqparent, const char *name, TQWidget::WFlags flags) :
- TQWidget(tqparent, name, flags)
+KMyMoneySelector::KMyMoneySelector(TQWidget *parent, const char *name, TQWidget::WFlags flags) :
+ TQWidget(parent, name, flags)
{
m_selMode = TQListView::Single;
@@ -47,9 +47,9 @@ KMyMoneySelector::KMyMoneySelector(TQWidget *tqparent, const char *name, TQWidge
m_listView->setSorting(-1);
- if(tqparent) {
- setFocusProxy(tqparent->focusProxy());
- m_listView->setFocusProxy(tqparent->focusProxy());
+ if(parent) {
+ setFocusProxy(parent->focusProxy());
+ m_listView->setFocusProxy(parent->focusProxy());
}
m_listView->setAllColumnsShowFocus(true);
@@ -144,17 +144,17 @@ TQListViewItem* KMyMoneySelector::newTopItem(const TQString& name, const TQStrin
return p;
}
-TQListViewItem* KMyMoneySelector::newItem(TQListViewItem* tqparent, const TQString& name, const TQString& key, const TQString& id)
+TQListViewItem* KMyMoneySelector::newItem(TQListViewItem* parent, const TQString& name, const TQString& key, const TQString& id)
{
TQListViewItem* p;
if(m_selMode == TQListView::Multi) {
- KMyMoneyCheckListItem* q = new KMyMoneyCheckListItem(tqparent, name, key, id);
+ KMyMoneyCheckListItem* q = new KMyMoneyCheckListItem(parent, name, key, id);
connect(q, TQT_SIGNAL(stateChanged(bool)), this, TQT_SIGNAL(stateChanged(void)));
p = static_cast<TQListViewItem*> (q);
} else {
- KMyMoneyListViewItem* q = new KMyMoneyListViewItem(tqparent, name, key, id);
+ KMyMoneyListViewItem* q = new KMyMoneyListViewItem(parent, name, key, id);
p = static_cast<TQListViewItem*> (q);
}
@@ -542,9 +542,9 @@ int KMyMoneySelector::slotMakeCompletion(const TQRegExp& exp)
// The way out of this is as follows: Make all items visible.
// Then go through the list again and perform the checks.
// If an item does not have any tqchildren (last leaf in the tree view)
// perform the check. Then check recursively on the tqparent of this
// leaf that it has no visible tqchildren. If that is the case, make the
// tqparent invisible and continue this check with it's tqparent.
while((it_v = it.current()) != 0) {
it_v->setVisible(true);
++it;
@@ -559,15 +559,15 @@ int KMyMoneySelector::slotMakeCompletion(const TQRegExp& exp)
if(!match(exp, it_v)) {
// this is a node which does not contain the
// text and does not have tqchildren. So we can
// safely hide it. Then we check, if the tqparent
// has more tqchildren which are still visible. If
// none are found, the tqparent node is hidden also. We
// continue until the top of the tree or until we
// find a node that still has visible tqchildren.
bool hide = true;
while(hide) {
it_v->setVisible(false);
- it_v = it_v->tqparent();
+ it_v = it_v->parent();
if(it_v && it_v->isSelectable()) {
hide = !match(exp, it_v);
TQListViewItem* child = it_v->firstChild();
@@ -591,11 +591,11 @@ int KMyMoneySelector::slotMakeCompletion(const TQRegExp& exp)
// to display all child nodes in this case, so we need
// to advance the iterator to the next sibling of the
// current node. This could well be the sibling of a
- // tqparent or grandtqparent node.
+ // parent or grandparent node.
TQListViewItem* curr = it_v;
TQListViewItem* item;
while((item = curr->nextSibling()) == 0) {
- curr = curr->tqparent();
+ curr = curr->parent();
if(curr == 0)
break;
if(match(exp, curr))
@@ -542,9 +542,9 @@ int KMyMoneySelector::slotMakeCompletion(const TQRegExp& exp)
// Then go through the list again and perform the checks.
// If an item does not have any tqchildren (last leaf in the tree view)
- // perform the check. Then check recursively on the tqparent of this
+ // perform the check. Then check recursively on the parent of this
// leaf that it has no visible tqchildren. If that is the case, make the
@@ -542,9 +542,9 @@ int KMyMoneySelector::slotMakeCompletion(const TQRegExp& exp)
// leaf that it has no visible tqchildren. If that is the case, make the
- // tqparent invisible and continue this check with it's tqparent.
+ // parent invisible and continue this check with it's parent.
while((it_v = it.current()) != 0) {
it_v->setVisible(true);
@@ -559,15 +559,15 @@ int KMyMoneySelector::slotMakeCompletion(const TQRegExp& exp)
// this is a node which does not contain the
// text and does not have tqchildren. So we can
- // safely hide it. Then we check, if the tqparent
+ // safely hide it. Then we check, if the parent
// has more tqchildren which are still visible. If
@@ -559,15 +559,15 @@ int KMyMoneySelector::slotMakeCompletion(const TQRegExp& exp)
// has more tqchildren which are still visible. If
- // none are found, the tqparent node is hidden also. We
+ // none are found, the parent node is hidden also. We
// continue until the top of the tree or until we
// find a node that still has visible tqchildren.